﻿Fluke                                                       MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Fluke 5320A-LOAD Certified Value
DATE:                  2010-06-16 11:23:19
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       177
=============================================================================
#
#  Procedure Author:
#        DFM, DAC
#
#  Model(s) Covered:
#        Various
#
#  Compatibility:
#        MET/CAL or 5500/CAL 7.20 or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        5320A-LOAD.ini
#
#  Additional Equipment Required:
#        None
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
#  This procedure is used to access an initialization file containing the
#  5320A-LOAD.ini certified resistance values.  If the file does not exit, the
#  operator will be prompted for the calibration date and the certified
#  values to create the file.
#
#  Initialization file format:
#
#        [<asset number>]
#        Cal_Date        = <calibration date>
#        10kOhm          = <certified value>
#        35kOhm          = <certified value>
#        50kOhm          = <certified value>
#        100kOhm         = <certified value>
#        250kOhm         = <certified value>
#        500kOhm         = <certified value>
#        1MOhm           = <certified value>
#        5MOhm           = <certified value>
#
#  Example:  Fluke 5320A, asset number 1234567
#
#        [1234567]
#        Cal_Date        = 6-Apr-07
#        10kOhm          = 10.1726E+3
#        35kOhm          = 34.7228E+3
#        50kOhm          = 51.4049E+3
#        100kOhm         = 99.633E+3
#        250kOhm         = 250.014E+3
#        500kOhm         = 507.278E+3
#        1MOhm           = 1.01772E+6
#        5MOhm           = 5.13579E+6
#
#  In use, the following example procedure lines might be used:
#
#    1.001  STD          Fluke 5320A-LOAD
#
#    1.003  MATH         @NominalValue = "5MOhm"
#    1.006  CALL         Sub Fluke 5320A-LOAD Certified Value
#
#  The subprocedure returns the certified value in MEM.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Initialize error flag to false.
  1.001  MATH         @Error = 0

  1.002  MATH         InstrumentName = "Fluke 5320A-LOAD"
  1.003  MATH         IniFile        = "5320A-LOAD.ini"
# Get asset number of configured device.
  1.004  MATH         AssetNum = ASSET(InstrumentName)

  1.005  IF           EMPTY(AssetNum)
  1.006  DISP         No asset number specified for configured instrument:
  1.006  DISP         [V InstrumentName].
  1.006  DISP
  1.006  DISP         You must terminate the procedure, then press F12 or
  1.006  DISP         select Configure->Instruments to specify the asset
  1.006  DISP         number of [V InstrumentName].
  1.007  MATH         @Error = 1
  1.008  END
  1.009  ENDIF

  1.010  MATH         CalDateFile = RIF(IniFile, AssetNum, "Cal_Date")
  1.011  MATH         CalDateDB   = CAL(AssetNum, -1, 2301)

  1.012  IF           NOT(ZCMPI(CalDateFile, CalDateDB))
  1.013  DISP         5320A-LOAD.ini does not exist, or is out of date.
  1.013  DISP
  1.013  DISP         You will now be prompted for the certified resistance
  1.013  DISP         values for 5320A-LOAD, asset number [V AssetNum],
  1.013  DISP         calibrated on [V CalDateDB].

  1.014  DO
  1.015  MEMI         Enter certified value for 10 kOhm in kilohms:
  1.016  MATH         MEM = MEM * 1E+3
  1.017  MATH         WIF(IniFile, AssetNum, "10kOhm", MEM)

  1.018  MEMI         Enter certified value for 35 kOhm in kilohms:
  1.019  MATH         MEM = MEM * 1E+3
  1.020  MATH         WIF(IniFile, AssetNum, "35kOhm", MEM)

  1.021  MEMI         Enter certified value for 50 kOhm in kilohms:
  1.022  MATH         MEM = MEM * 1E+3
  1.023  MATH         WIF(IniFile, AssetNum, "50kOhm", MEM)

  1.024  MEMI         Enter certified value for 100 kOhm in kilohms:
  1.025  MATH         MEM = MEM * 1E+3
  1.026  MATH         WIF(IniFile, AssetNum, "100kOhm", MEM)

  1.027  MEMI         Enter certified value for 250 kOhm in kilohms:
  1.028  MATH         MEM = MEM * 1E+3
  1.029  MATH         WIF(IniFile, AssetNum, "250kOhm", MEM)

  1.030  MEMI         Enter certified value for 500 kOhm in kilohms:
  1.031  MATH         MEM = MEM * 1E+3
  1.032  MATH         WIF(IniFile, AssetNum, "500kOhm", MEM)

  1.033  MEMI         Enter certified value for 1 MOhm in megohms:
  1.034  MATH         MEM = MEM * 1E+6
  1.035  MATH         WIF(IniFile, AssetNum, "1MOhm", MEM)

  1.036  MEMI         Enter certified value for 5 MOhm in megohms:
  1.037  MATH         MEM = MEM * 1E+6
  1.038  MATH         WIF(IniFile, AssetNum, "5MOhm", MEM)

  1.039  MATH         Res10kOhm  = RIF(IniFile, AssetNum, "10kOhm")
  1.040  MATH         Res35kOhm  = RIF(IniFile, AssetNum, "35kOhm")
  1.041  MATH         Res50kOhm  = RIF(IniFile, AssetNum, "50kOhm")
  1.042  MATH         Res100kOhm = RIF(IniFile, AssetNum, "100kOhm")
  1.043  MATH         Res250kOhm = RIF(IniFile, AssetNum, "250kOhm")
  1.044  MATH         Res500kOhm = RIF(IniFile, AssetNum, "500kOhm")
  1.045  MATH         Res1MOhm   = RIF(IniFile, AssetNum, "1MOhm")
  1.046  MATH         Res5MOhm   = RIF(IniFile, AssetNum, "5MOhm")

  1.047  OPBR         -z
  1.047  OPBR         10kOhm  = [V Res10kOhm]
  1.047  OPBR         35kOhm  = [V Res35kOhm]
  1.047  OPBR         50kOhm  = [V Res50kOhm]
  1.047  OPBR         100kOhm = [V Res100kOhm]
  1.047  OPBR         250kOhm = [V Res250kOhm]
  1.047  OPBR         500kOhm = [V Res500kOhm]
  1.047  OPBR         1MOhm   = [V Res1MOhm]
  1.047  OPBR         5MOhm   = [V Res5MOhm]
  1.047  OPBR
  1.047  OPBR         Are all the entries correct?
  1.048  UNTIL        MEM1

  1.049  MATH         WIF(IniFile, AssetNum, "Cal_Date", CalDateDB)
  1.050  ENDIF        ; NOT(ZCMPI(CalDateFile, CalDateDB))

  1.051  MATH         MEM = RIF(IniFile, AssetNum, @NominalValue)
  1.052  END
